@@ -33,18 +33,22 @@
 #include "floppy_v_out.xpm"
 #include "floppy_h_in.xpm"
 #include "floppy_h_out.xpm"
+
 #include "cdrom_v_in.xpm"
 #include "cdrom_v_out.xpm"
 #include "cdrom_h_in.xpm"
 #include "cdrom_h_out.xpm"
+
 #include "cdburn_v_in.xpm"
 #include "cdburn_v_out.xpm"
 #include "cdburn_h_in.xpm"
 #include "cdburn_h_out.xpm"
+
 #include "zipdrive_v_in.xpm"
 #include "zipdrive_v_out.xpm"
 #include "zipdrive_h_in.xpm"
 #include "zipdrive_h_out.xpm"
+
 #include "harddisk_v_in.xpm"
 #include "harddisk_v_out.xpm"
 #include "harddisk_h_in.xpm"
@@ -55,6 +59,11 @@
 #include "jazdrive_v_in.xpm"
 #include "jazdrive_v_out.xpm"
 
+#include "usbstick_v_in.xpm"
+#include "usbstick_v_out.xpm"
+#include "usbstick_h_in.xpm"
+#include "usbstick_h_out.xpm"
+
 
 static gboolean applet_factory (PanelApplet *applet, const gchar *iid,
 				gpointer data);
@@ -140,6 +149,11 @@ static IconData icon_list[] = {
 	 jazdrive_h_out_xpm,
 	 jazdrive_v_in_xpm,
 	 jazdrive_v_out_xpm},
+	{
+	 usbstick_h_in_xpm,
+	 usbstick_h_out_xpm,
+	 usbstick_v_in_xpm,
+	 usbstick_v_out_xpm},
 	{
 	 NULL,
 	 NULL,
@@ -147,7 +161,7 @@ static IconData icon_list[] = {
 	 NULL}
 };
 
-static gint icon_list_count = 6;
+static gint icon_list_count = 7;
 
 /* Bonobo Verbs for our popup menu */
 static const BonoboUIVerb applet_menu_verbs [] = {
@@ -192,6 +206,7 @@ applet_fill (PanelApplet *applet)
 	DriveData *dd;
 	BonoboUIComponent *component;
 	gchar *tmp_path;
+	AtkObject *atk_obj;
 	
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/drivemount-applet.png");
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
@@ -227,6 +242,17 @@ applet_fill (PanelApplet *applet)
                                            applet_menu_verbs,
                                            dd);
 
+	if (panel_applet_get_locked_down (PANEL_APPLET (applet))) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/Properties",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	component = panel_applet_get_popup_component (PANEL_APPLET (applet));
 
 	tmp_path = gnome_is_program_in_path ("eject");
@@ -237,6 +263,10 @@ applet_fill (PanelApplet *applet)
 		g_free (tmp_path);
 
 	redraw_pixmap (dd);
+
+	atk_obj = gtk_widget_get_accessible (dd->button);
+	atk_object_set_name (atk_obj, _("Disk Mounter"));
+
 	gtk_widget_show (GTK_WIDGET (applet));
 	start_callback_update (dd);
 	return TRUE;
@@ -250,6 +280,8 @@ create_drive_widget (PanelApplet *applet)
 	dd = g_new0 (DriveData, 1);
 	dd->applet = GTK_WIDGET (applet);
 
+	dd->about_dialog = NULL;
+
 	properties_load (dd);
 
 	dd->button = gtk_button_new ();
@@ -376,10 +408,8 @@ destroy_drive_widget (GtkWidget *widget, gpointer data)
 		dd->error_dialog = NULL;
 	}
 
-	if (dd->tooltips != NULL) {
-		g_object_unref (G_OBJECT (dd->tooltips));
-		dd->tooltips = NULL;
-	}
+	if (dd->about_dialog != NULL)
+		gtk_widget_destroy (dd->about_dialog);
 
 	g_free (dd->custom_icon_in);
 	g_free (dd->custom_icon_out);
@@ -497,7 +527,6 @@ about_cb (BonoboUIComponent *uic,
 	  DriveData         *drivemount,
 	  const char        *verb)
 {
-	static GtkWidget *about = NULL;
    	GdkPixbuf        *pixbuf;
    	GError           *error = NULL;
    	gchar            *file;
@@ -509,15 +538,18 @@ about_cb (BonoboUIComponent *uic,
 	};
 
 	const gchar *documenters[] = {
+	        "Dan Mueth <muet@alumni.uchicago.edu>",
+                "John Fleck <jfleck@inkstain.net>",
 		NULL
 	};
 
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about) {
-		gtk_window_set_screen (GTK_WINDOW (about),
-				       gtk_widget_get_screen (drivemount->applet));
-		gtk_window_present (GTK_WINDOW (about));
+	if (drivemount->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (drivemount->about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (drivemount->applet)));
+	
+		gtk_window_present (GTK_WINDOW (drivemount->about_dialog));
 		return;
 	}
 
@@ -530,7 +562,7 @@ about_cb (BonoboUIComponent *uic,
 		g_error_free (error);
 	}
 
-	about = gnome_about_new (_("Disk Mounter"), VERSION,
+	drivemount->about_dialog = gnome_about_new (_("Disk Mounter"), VERSION,
 				 _("(C) 1999-2001 The GNOME Hackers\n"),
 				 _
 				 ("Applet for mounting and unmounting block volumes."),
@@ -541,12 +573,14 @@ about_cb (BonoboUIComponent *uic,
 	if (pixbuf) 
    		gdk_pixbuf_unref (pixbuf);
    
-   	gtk_window_set_wmclass (GTK_WINDOW (about), "disk mounter", "Disk Mounter");
-	gtk_window_set_screen (GTK_WINDOW (about),
+   	gtk_window_set_wmclass (GTK_WINDOW (drivemount->about_dialog), "disk mounter", "Disk Mounter");
+	gtk_window_set_screen (GTK_WINDOW (drivemount->about_dialog),
 			       gtk_widget_get_screen (drivemount->applet));
-   	g_signal_connect (G_OBJECT (about), "destroy",
-			  G_CALLBACK (gtk_widget_destroyed), &about);
-	gtk_widget_show (about);
+
+	g_signal_connect (G_OBJECT (drivemount->about_dialog), "destroy",
+			  G_CALLBACK (gtk_widget_destroyed), &drivemount->about_dialog);
+
+	gtk_widget_show (drivemount->about_dialog);
 }
 
 /*
@@ -671,7 +705,7 @@ update_pixmap (DriveData *dd, gint t)
 
 		if (pixbuf) {
 			width = gdk_pixbuf_get_width (pixbuf);
-			height = gdk_pixbuf_get_width (pixbuf);
+			height = gdk_pixbuf_get_height (pixbuf);
 
 			if (dd->orient == PANEL_APPLET_ORIENT_LEFT
 			    || dd->orient == PANEL_APPLET_ORIENT_RIGHT) {
@@ -989,7 +1023,7 @@ hig_dialog_new (GtkWindow      *parent,
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
   
 	dialog_vbox = GTK_DIALOG (dialog)->vbox;
-	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 12);
+	gtk_box_set_spacing (GTK_BOX (dialog_vbox), 14);
 
 	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox), hbox, FALSE, FALSE, 0);
