@@ -109,6 +109,8 @@
 		
 		GtkWidget *fontDialog;
 
+		GtkWidget *about_dialog;
+
 		GtkWidget * pb;
 		
 		gtik_properties props; 
@@ -757,7 +759,6 @@ static gint updateOutput(gpointer data)
 	static void about_cb (BonoboUIComponent *uic,
 			      StockData         *stockdata, 
 			      const gchar       *verbname) {
-		GtkWidget *about;
 		GdkPixbuf *pixbuf;
 		GError    *error = NULL;
 		gchar     *file;
@@ -769,12 +770,17 @@ static gint updateOutput(gpointer data)
 		};
 		
 		const gchar *documenters[] = {
+		        "Sun GNOME Documentation Team <gdocteam@sun.com>",
 			NULL
 		};
 
 		const gchar *translator_credits = _("translator_credits");
-		
-		
+
+		if (stockdata->about_dialog) {
+			gtk_window_present (GTK_WINDOW (stockdata->about_dialog));
+			return;
+		}
+
 		file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
 			"gnome-money.png", FALSE, NULL);
 		
@@ -788,7 +794,7 @@ static gint updateOutput(gpointer data)
 			g_error_free (error);
 		}
 		
-		about = gnome_about_new (_("Stock Ticker"), VERSION,
+		stockdata->about_dialog = gnome_about_new (_("Stock Ticker"), VERSION,
 		"(C) 2000 Jayson Lorenzen, Jim Garrison, Rached Blili",
 		_("This program connects to "
 		"a popular site and downloads current stock quotes.  "
@@ -804,9 +810,13 @@ static gint updateOutput(gpointer data)
 		if (pixbuf)
 			gdk_pixbuf_unref (pixbuf);
 
-		gtk_window_set_screen (GTK_WINDOW (about),
+		gtk_window_set_screen (GTK_WINDOW (stockdata->about_dialog),
 				       gtk_widget_get_screen (stockdata->applet));
-		gtk_widget_show (about);
+
+		g_signal_connect(G_OBJECT (stockdata->about_dialog), "destroy",
+				 G_CALLBACK (gtk_widget_destroyed), &stockdata->about_dialog);
+
+		gtk_widget_show (stockdata->about_dialog);
 
 		return;
 	}
@@ -1769,6 +1779,8 @@ static gint updateOutput(gpointer data)
 		GtkWidget * vbox;
 		GtkWidget * frame;
 		GtkWidget *event;
+		GtkWidget *left_arrow;
+		GtkWidget *right_arrow;
 
 		gnome_vfs_init();
 		
@@ -1788,8 +1800,16 @@ static gint updateOutput(gpointer data)
 		properties_load(stockdata);	
 
 		vbox = gtk_hbox_new (FALSE,0);
-		stockdata->leftButton = gtk_button_new_with_label("<<");
-		stockdata->rightButton = gtk_button_new_with_label(">>");
+		stockdata->leftButton = gtk_button_new();
+		stockdata->rightButton = gtk_button_new();
+		left_arrow = gtk_arrow_new (GTK_ARROW_LEFT, GTK_SHADOW_OUT);
+		right_arrow = gtk_arrow_new (GTK_ARROW_RIGHT, GTK_SHADOW_OUT);
+		gtk_container_add (GTK_CONTAINER (stockdata->leftButton),
+				   left_arrow);
+		gtk_container_add (GTK_CONTAINER (stockdata->rightButton),
+				   right_arrow);
+		gtk_widget_show_all (stockdata->leftButton);
+		gtk_widget_show_all (stockdata->rightButton);				
 		gtk_signal_connect (GTK_OBJECT (stockdata->leftButton),
 					"clicked",
 					GTK_SIGNAL_FUNC(zipLeft),stockdata);
@@ -1815,6 +1835,7 @@ static gint updateOutput(gpointer data)
 		gtk_tooltips_set_tip(stockdata->tooltips, event, _("Stock Ticker\nGet continuously updated stock quotes"), NULL);
 
 		access_drawing_area = stockdata->drawing_area = GTK_WIDGET (custom_drawing_area_new());
+		g_object_add_weak_pointer (G_OBJECT (access_drawing_area), (gpointer *)&access_drawing_area);
 		gtk_drawing_area_size(GTK_DRAWING_AREA (stockdata->drawing_area),
 						stockdata->props.width,-1);
 
@@ -1940,6 +1961,9 @@ static gint updateOutput(gpointer data)
 			g_free (stockdata->configFileName);
 		if (stockdata->my_font)
 			pango_font_description_free (stockdata->my_font);
+
+		if (stockdata->about_dialog)
+			 gtk_widget_destroy (stockdata->about_dialog); 
 		
 		if (stockdata->pb)
 			gtk_widget_destroy (stockdata->pb);
@@ -2219,7 +2243,11 @@ static gint updateOutput(gpointer data)
 	}
 
 	static AtkObject* gtik_vbox_accessible_ref_child(AtkObject *obj, gint i){
-		return (gtk_widget_get_accessible(access_drawing_area));
+		if (i == 0 && access_drawing_area)
+			return g_object_ref (gtk_widget_get_accessible(access_drawing_area));
+		else
+			return NULL;
+		
 	}
 
 	gchar* gtik_get_text(void) {
