@@ -759,10 +759,14 @@ password_response_cb (GtkWidget  *dialog,
 
 	switch (response_id) {
 		GtkWidget *entry;
+		GtkWidget *save_toggle_button;
 
 	case GTK_RESPONSE_OK:
 		entry = g_object_get_data (G_OBJECT (dialog), "password_entry");
 		mc->real_password = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
+		save_toggle_button = g_object_get_data (G_OBJECT (dialog), "save_password");
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (save_toggle_button)))
+			 remote_password_save_toggled (GTK_TOGGLE_BUTTON (save_toggle_button), mc);
 		check_remote_mailbox (mc);
 		break;
 	}
@@ -810,16 +814,11 @@ get_remote_password (MailCheck *mc)
 	set_atk_name_description (entry, _("Password Entry box"), "");
 	set_atk_relation (entry, label, ATK_RELATION_LABELLED_BY);	
 	gtk_entry_set_visibility (GTK_ENTRY (entry), FALSE);
+	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 	gtk_box_pack_start (GTK_BOX (hbox), entry, FALSE, FALSE, 0);
 	gtk_widget_show_all (hbox);
 	gtk_widget_grab_focus (GTK_WIDGET (entry));
 
-	g_signal_connect (G_OBJECT(entry), "focus_out_event",
-			 G_CALLBACK(focus_out_cb), mc);
-
-	g_signal_connect (G_OBJECT(entry), "activate",
-			  G_CALLBACK(remote_password_changed), mc);
-
 	hbox = gtk_hbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox, 
 			    FALSE, FALSE, GNOME_PAD_SMALL);
@@ -844,15 +843,13 @@ get_remote_password (MailCheck *mc)
 	gtk_widget_show (save_password_checkbox);
 	gtk_box_pack_start (GTK_BOX (hbox), save_password_checkbox, FALSE, FALSE, 0);
 	
-	g_signal_connect (G_OBJECT (save_password_checkbox), "toggled", 
-			  G_CALLBACK(remote_password_save_toggled), mc);
-
 	gtk_window_set_screen (GTK_WINDOW (dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (mc->applet)));
 
 	g_signal_connect (dialog, "response",
                           G_CALLBACK (password_response_cb), mc);
 
+	g_object_set_data (G_OBJECT (dialog), "save_password", save_password_checkbox);
 	g_object_set_data (G_OBJECT (dialog), "password_entry", entry);
 	gtk_widget_show (GTK_WIDGET (dialog));
 }
@@ -1044,13 +1041,9 @@ mailcheck_load_animation (MailCheck *mc, const char *fname)
 					   gtk_widget_get_screen (GTK_WIDGET (mc->applet))),
 					   width, height, -1);
 
-	gdk_pixbuf_render_to_drawable (pb,
-				       mc->email_pixmap,
-				       mc->da->style->black_gc,
-				       0, 0, 0, 0,
-				       width, height,
-				       GDK_RGB_DITHER_NORMAL,
-				       0, 0);
+	gdk_draw_pixbuf (mc->email_pixmap, mc->da->style->black_gc, pb,
+			 0, 0, 0, 0, width, height,
+			 GDK_RGB_DITHER_NORMAL, 0, 0);
 	
 	g_object_unref (pb);
 	
@@ -1076,6 +1069,7 @@ after_mail_check (MailCheck *mc)
 {
 	static const char *supinfo[] = {"mailcheck", "new-mail", NULL};
 	char *text;
+	char *plural1, *plural2;
 
 	if (mc->anymail){
 		if(mc->mailbox_type == MAILBOX_LOCAL) {
@@ -1085,10 +1079,21 @@ after_mail_check (MailCheck *mc)
 				text = g_strdup(_("You have mail."));
 		}
 		else {
-			if(mc->unreadmail)
-				text = g_strdup_printf(_("%d unread/ %d messages"), mc->unreadmail, mc->totalmail);
+			if (mc->unreadmail) {
+				plural1 = g_strdup(ngettext ("%d unread", "%d unread",  mc->unreadmail));
+				plural2 = g_strdup(ngettext ("%d message", "%d messages", mc->totalmail));
+
+				/* translators: this is of the form "%d unread/%d messages" */
+				text = g_strdup_printf(_("%s/%s"), plural1, plural2);
+
+				g_free (plural1);
+				g_free (plural2);
+			}
 			else
-				text = g_strdup_printf(_("%d messages"), mc->totalmail);
+				text = g_strdup_printf(ngettext ("%d message",
+								 "%d messages",
+								 mc->totalmail),
+						       mc->totalmail);
 		} 
 	}
 	else
@@ -2008,6 +2013,11 @@ mailcheck_properties_page (MailCheck *mc)
 	GtkObject *freq_a;
 	gchar *title;
 	gboolean writable;
+	GConfClient *client;
+	gboolean inhibit_command_line;
+
+	client = gconf_client_get_default ();
+	inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
 
 	mc->type = 0;
 
@@ -2146,122 +2156,124 @@ mailcheck_properties_page (MailCheck *mc)
 		hard_set_sensitive (l, FALSE);
 		hard_set_sensitive (animation_option_menu, FALSE);
 	}
-	
-	category_vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (categories_vbox), category_vbox, TRUE, TRUE, 0);
-	gtk_widget_show (category_vbox);
 
-	title = g_strconcat ("<span weight=\"bold\">", _("Commands"), "</span>", NULL);
-	label = gtk_label_new (title);
-	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-	gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	g_free (title);
+	if ( ! inhibit_command_line) {
+		category_vbox = gtk_vbox_new (FALSE, 6);
+		gtk_box_pack_start (GTK_BOX (categories_vbox), category_vbox, TRUE, TRUE, 0);
+		gtk_widget_show (category_vbox);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (category_vbox), hbox, TRUE, TRUE, 0);
-        gtk_widget_show (hbox);
+		title = g_strconcat ("<span weight=\"bold\">", _("Commands"), "</span>", NULL);
+		label = gtk_label_new (title);
+		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+		gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
+		gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+		gtk_box_pack_start (GTK_BOX (category_vbox), label, FALSE, FALSE, 0);
+		gtk_widget_show (label);
+		g_free (title);
 
-	indent = gtk_label_new (HIG_IDENTATION);
-	gtk_label_set_justify (GTK_LABEL (indent), GTK_JUSTIFY_LEFT);
-	gtk_box_pack_start (GTK_BOX (hbox), indent, FALSE, FALSE, 0);
-	gtk_widget_show (indent);
+		hbox = gtk_hbox_new (FALSE, 0);
+		gtk_box_pack_start (GTK_BOX (category_vbox), hbox, TRUE, TRUE, 0);
+		gtk_widget_show (hbox);
 
-	control_vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (hbox), control_vbox, TRUE, TRUE, 0);
-	gtk_widget_show (control_vbox);
+		indent = gtk_label_new (HIG_IDENTATION);
+		gtk_label_set_justify (GTK_LABEL (indent), GTK_JUSTIFY_LEFT);
+		gtk_box_pack_start (GTK_BOX (hbox), indent, FALSE, FALSE, 0);
+		gtk_widget_show (indent);
 
-	table = gtk_table_new (3, 2, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 0);
-	gtk_widget_show(table);
-	gtk_container_add (GTK_CONTAINER (control_vbox), table);
+		control_vbox = gtk_vbox_new (FALSE, 6);
+		gtk_box_pack_start (GTK_BOX (hbox), control_vbox, TRUE, TRUE, 0);
+		gtk_widget_show (control_vbox);
 
-	l = gtk_check_button_new_with_mnemonic(_("Before each _update:"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->pre_check_enabled);
-	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(pre_check_toggled), mc);
-	gtk_widget_show(l);
-	mc->pre_check_cmd_check = l;
-	if ( ! key_writable (mc->applet, "exec_enabled"))
-		hard_set_sensitive (l, FALSE);
+		table = gtk_table_new (3, 2, FALSE);
+		gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+		gtk_table_set_row_spacings (GTK_TABLE (table), 6);
+		gtk_container_set_border_width (GTK_CONTAINER (table), 0);
+		gtk_widget_show(table);
+		gtk_container_add (GTK_CONTAINER (control_vbox), table);
 
-	gtk_table_attach (GTK_TABLE (table), mc->pre_check_cmd_check, 
-			  0, 1, 0, 1, GTK_FILL, 0, 0, 0);
-			   
+		l = gtk_check_button_new_with_mnemonic(_("Before each _update:"));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->pre_check_enabled);
+		g_signal_connect(G_OBJECT(l), "toggled",
+				 G_CALLBACK(pre_check_toggled), mc);
+		gtk_widget_show(l);
+		mc->pre_check_cmd_check = l;
+		if ( ! key_writable (mc->applet, "exec_enabled"))
+			hard_set_sensitive (l, FALSE);
 
-	mc->pre_check_cmd_entry = gtk_entry_new();
-	if(mc->pre_check_cmd)
-		gtk_entry_set_text(GTK_ENTRY(mc->pre_check_cmd_entry), 
-				   mc->pre_check_cmd);
-	set_atk_name_description (mc->pre_check_cmd_entry, _("Command to execute before each update"), "");
-	set_atk_relation (mc->pre_check_cmd_entry, mc->pre_check_cmd_check, ATK_RELATION_CONTROLLED_BY);
-	set_atk_relation (mc->pre_check_cmd_check, mc->pre_check_cmd_entry, ATK_RELATION_CONTROLLER_FOR);
-	soft_set_sensitive (mc->pre_check_cmd_entry, mc->pre_check_enabled);
-	g_signal_connect(G_OBJECT(mc->pre_check_cmd_entry), "changed",
-			   G_CALLBACK(pre_check_changed), mc);
-	gtk_widget_show(mc->pre_check_cmd_entry);
-	gtk_table_attach_defaults (GTK_TABLE (table), mc->pre_check_cmd_entry,
-				   1, 2, 0, 1);
-	if ( ! key_writable (mc->applet, "exec_command"))
-		hard_set_sensitive (mc->pre_check_cmd_entry, FALSE);
+		gtk_table_attach (GTK_TABLE (table), mc->pre_check_cmd_check, 
+				  0, 1, 0, 1, GTK_FILL, 0, 0, 0);
 
-	l = gtk_check_button_new_with_mnemonic (_("When new mail _arrives:"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->newmail_enabled);
-	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(newmail_toggled), mc);
-	gtk_widget_show(l);
-	gtk_table_attach (GTK_TABLE (table), l, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
-	mc->newmail_cmd_check = l;
-	if ( ! key_writable (mc->applet, "newmail_enabled"))
-		hard_set_sensitive (l, FALSE);
 
-	mc->newmail_cmd_entry = gtk_entry_new();
-	if (mc->newmail_cmd) {
-		gtk_entry_set_text(GTK_ENTRY(mc->newmail_cmd_entry),
-				   mc->newmail_cmd);
-	}
-	set_atk_name_description (mc->newmail_cmd_entry, _("Command to execute when new mail arrives"), "");
-	set_atk_relation (mc->newmail_cmd_entry, mc->newmail_cmd_check, ATK_RELATION_CONTROLLED_BY);
-	set_atk_relation (mc->newmail_cmd_check, mc->newmail_cmd_entry, ATK_RELATION_CONTROLLER_FOR);
-	soft_set_sensitive (mc->newmail_cmd_entry, mc->newmail_enabled);
-	g_signal_connect(G_OBJECT (mc->newmail_cmd_entry), "changed",
-			   G_CALLBACK(newmail_changed), mc);
-	gtk_widget_show(mc->newmail_cmd_entry);
-	gtk_table_attach_defaults (GTK_TABLE (table), mc->newmail_cmd_entry,
-				    1, 2, 1, 2);
-	if ( ! key_writable (mc->applet, "newmail_command"))
-		hard_set_sensitive (mc->newmail_cmd_entry, FALSE);
+		mc->pre_check_cmd_entry = gtk_entry_new();
+		if(mc->pre_check_cmd)
+			gtk_entry_set_text(GTK_ENTRY(mc->pre_check_cmd_entry), 
+					   mc->pre_check_cmd);
+		set_atk_name_description (mc->pre_check_cmd_entry, _("Command to execute before each update"), "");
+		set_atk_relation (mc->pre_check_cmd_entry, mc->pre_check_cmd_check, ATK_RELATION_CONTROLLED_BY);
+		set_atk_relation (mc->pre_check_cmd_check, mc->pre_check_cmd_entry, ATK_RELATION_CONTROLLER_FOR);
+		soft_set_sensitive (mc->pre_check_cmd_entry, mc->pre_check_enabled);
+		g_signal_connect(G_OBJECT(mc->pre_check_cmd_entry), "changed",
+				 G_CALLBACK(pre_check_changed), mc);
+		gtk_widget_show(mc->pre_check_cmd_entry);
+		gtk_table_attach_defaults (GTK_TABLE (table), mc->pre_check_cmd_entry,
+					   1, 2, 0, 1);
+		if ( ! key_writable (mc->applet, "exec_command"))
+			hard_set_sensitive (mc->pre_check_cmd_entry, FALSE);
 
-        l = gtk_check_button_new_with_mnemonic (_("When double clicke_d:"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->clicked_enabled);
-	g_signal_connect(G_OBJECT(l), "toggled",
-			   G_CALLBACK(clicked_toggled), mc);
-        gtk_widget_show(l);
-	gtk_table_attach (GTK_TABLE (table), l, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
-	mc->clicked_cmd_check = l;
-	if ( ! key_writable (mc->applet, "clicked_enabled"))
-		hard_set_sensitive (l, FALSE);
+		l = gtk_check_button_new_with_mnemonic (_("When new mail _arrives:"));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->newmail_enabled);
+		g_signal_connect(G_OBJECT(l), "toggled",
+				 G_CALLBACK(newmail_toggled), mc);
+		gtk_widget_show(l);
+		gtk_table_attach (GTK_TABLE (table), l, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+		mc->newmail_cmd_check = l;
+		if ( ! key_writable (mc->applet, "newmail_enabled"))
+			hard_set_sensitive (l, FALSE);
 
-        mc->clicked_cmd_entry = gtk_entry_new();
-        if(mc->clicked_cmd) {
-		gtk_entry_set_text(GTK_ENTRY(mc->clicked_cmd_entry), 
-				   mc->clicked_cmd);
-        }
+		mc->newmail_cmd_entry = gtk_entry_new();
+		if (mc->newmail_cmd) {
+			gtk_entry_set_text(GTK_ENTRY(mc->newmail_cmd_entry),
+					   mc->newmail_cmd);
+		}
+		set_atk_name_description (mc->newmail_cmd_entry, _("Command to execute when new mail arrives"), "");
+		set_atk_relation (mc->newmail_cmd_entry, mc->newmail_cmd_check, ATK_RELATION_CONTROLLED_BY);
+		set_atk_relation (mc->newmail_cmd_check, mc->newmail_cmd_entry, ATK_RELATION_CONTROLLER_FOR);
+		soft_set_sensitive (mc->newmail_cmd_entry, mc->newmail_enabled);
+		g_signal_connect(G_OBJECT (mc->newmail_cmd_entry), "changed",
+				 G_CALLBACK(newmail_changed), mc);
+		gtk_widget_show(mc->newmail_cmd_entry);
+		gtk_table_attach_defaults (GTK_TABLE (table), mc->newmail_cmd_entry,
+					   1, 2, 1, 2);
+		if ( ! key_writable (mc->applet, "newmail_command"))
+			hard_set_sensitive (mc->newmail_cmd_entry, FALSE);
+
+		l = gtk_check_button_new_with_mnemonic (_("When double clicke_d:"));
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->clicked_enabled);
+		g_signal_connect(G_OBJECT(l), "toggled",
+				 G_CALLBACK(clicked_toggled), mc);
+		gtk_widget_show(l);
+		gtk_table_attach (GTK_TABLE (table), l, 0, 1, 2, 3, GTK_FILL, 0, 0, 0);
+		mc->clicked_cmd_check = l;
+		if ( ! key_writable (mc->applet, "clicked_enabled"))
+			hard_set_sensitive (l, FALSE);
+
+		mc->clicked_cmd_entry = gtk_entry_new();
+		if(mc->clicked_cmd) {
+			gtk_entry_set_text(GTK_ENTRY(mc->clicked_cmd_entry), 
+					   mc->clicked_cmd);
+		}
 		set_atk_name_description (mc->clicked_cmd_entry, _("Command to execute when clicked"), "");
 		set_atk_relation (mc->clicked_cmd_entry, mc->clicked_cmd_check, ATK_RELATION_CONTROLLED_BY);
 		set_atk_relation (mc->clicked_cmd_check, mc->clicked_cmd_entry, ATK_RELATION_CONTROLLER_FOR);
 		soft_set_sensitive (mc->clicked_cmd_entry, mc->clicked_enabled);
-        g_signal_connect(G_OBJECT(mc->clicked_cmd_entry), "changed",
-                           G_CALLBACK(clicked_changed), mc);
-        gtk_widget_show(mc->clicked_cmd_entry);
-	gtk_table_attach_defaults (GTK_TABLE (table), mc->clicked_cmd_entry,
-				   1, 2, 2, 3);
-	if ( ! key_writable (mc->applet, "clicked_command"))
-		hard_set_sensitive (mc->clicked_cmd_entry, FALSE);
+		g_signal_connect(G_OBJECT(mc->clicked_cmd_entry), "changed",
+				 G_CALLBACK(clicked_changed), mc);
+		gtk_widget_show(mc->clicked_cmd_entry);
+		gtk_table_attach_defaults (GTK_TABLE (table), mc->clicked_cmd_entry,
+					   1, 2, 2, 3);
+		if ( ! key_writable (mc->applet, "clicked_command"))
+			hard_set_sensitive (mc->clicked_cmd_entry, FALSE);
+	}
 
 	return vbox;
 }
@@ -2430,7 +2442,10 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 		NULL
 	};
 	const char *documenters [] = {
-	  NULL
+		"Eric Baudais <baudais@okstate.edu>",
+		"Telsa Gwynne <telsa@linuxchix.org>",
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
+	        NULL
 	};
 	const char *translator_credits = _("translator_credits");
 
@@ -2801,6 +2816,17 @@ mailcheck_applet_fill (PanelApplet *applet)
 					   NULL, 
 			        	   mailcheck_menu_verbs,
 					   mc);
+
+	if (panel_applet_get_locked_down (applet)) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (applet);
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/Preferences",
+					      "hidden", "1",
+					      NULL);
+	}
 	
 	gtk_label_set_text (GTK_LABEL (mc->label), _("Status not updated"));
 	set_tooltip (GTK_WIDGET (mc->applet), _("Status not updated"));
