@@ -156,6 +156,8 @@ typedef struct {
 
 	GtkAdjustment     *adj;
 
+	GtkWidget         *about_dialog;
+
 	GtkWidget         *applet;
 	GtkWidget         *frame;
 	GtkWidget         *image;
@@ -1226,6 +1228,8 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		g_source_remove (data->timeout);
 		data->timeout = 0;
 	}
+	if (data->about_dialog)
+		gtk_widget_destroy (data->about_dialog);
 	if (data->error_dialog)
 		gtk_widget_destroy (data->error_dialog);
 	if (data->tooltips)
@@ -1311,7 +1315,6 @@ mixer_about_cb (BonoboUIComponent *uic,
 		MixerData         *data,
 		const gchar       *verbname)
 {
-        static GtkWidget   *about     = NULL;
         GdkPixbuf *pixbuf             = NULL;
         gchar *file;
         static const gchar *authors[] = {
@@ -1325,10 +1328,8 @@ mixer_about_cb (BonoboUIComponent *uic,
 
 	const gchar *translator_credits = _("translator_credits");
 	
-        if (about) {
-		gtk_window_set_screen (GTK_WINDOW (about),
-				       gtk_widget_get_screen (data->applet));
-                gtk_window_present (GTK_WINDOW (about));
+        if (data->about_dialog) {
+                gtk_window_present (GTK_WINDOW (data->about_dialog));
                 return;
         }
         
@@ -1336,24 +1337,24 @@ mixer_about_cb (BonoboUIComponent *uic,
         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
         g_free (file);
 
-        about = gnome_about_new (_("Volume Control"), VERSION,
-                                 _("(C) 2001 Richard Hult"),
-                                 _("The volume control lets you set the volume level for your desktop."),
-				 authors,
-				 documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-                                 pixbuf);
+        data->about_dialog = gnome_about_new (_("Volume Control"), VERSION,
+                                              _("(C) 2001 Richard Hult"),
+                                              _("The volume control lets you set the volume level for your desktop."),
+                                              authors,
+                                              documenters,
+                                              strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+                                              pixbuf);
 
 	g_object_unref (pixbuf);
-	gtk_window_set_screen (GTK_WINDOW (about),
+	gtk_window_set_screen (GTK_WINDOW (data->about_dialog),
 			       gtk_widget_get_screen (data->applet));
-	gtk_window_set_wmclass (GTK_WINDOW(about), "volume control", "Volume Control");
-	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
-        g_signal_connect (G_OBJECT (about), "destroy",
+	gtk_window_set_wmclass (GTK_WINDOW(data->about_dialog), "volume control", "Volume Control");
+	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
+        g_signal_connect (G_OBJECT (data->about_dialog), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
-	                  &about);
+	                  &data->about_dialog);
 	
-        gtk_widget_show (about);
+        gtk_widget_show (data->about_dialog);
 }
 
 static void
@@ -1846,6 +1847,8 @@ mixer_applet_create (PanelApplet *applet)
 
 	mixer_load_volume_images (data);
 
+        data->about_dialog = NULL;
+
         data->tooltips = gtk_tooltips_new ();                                   
 	g_object_ref (data->tooltips);
 	gtk_object_sink (GTK_OBJECT (data->tooltips));
