@@ -34,10 +34,21 @@ LoadGraph *
 netload_applet_new(PanelApplet *applet, gpointer data)
 {
 	LoadGraph *g;
+	gint speed, size;
+	GError *error = NULL;
 	
-	g = load_graph_new(applet, 4, N_("Net Load"), 
-					panel_applet_gconf_get_int(applet, "speed", NULL), 
-					panel_applet_gconf_get_int(applet, "size", NULL), 
+	speed = panel_applet_gconf_get_int(applet, "speed", &error);
+	if (error) {
+		g_print ("%s \n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
+	speed = MAX (speed, 50);
+	size = panel_applet_gconf_get_int(applet, "size", NULL);
+	size = CLAMP (size, 10, 400); 
+	g = load_graph_new(applet, 5, N_("Net Load"), 
+					speed,
+					size, 
 					panel_applet_gconf_get_bool(applet, "view_netload", NULL), 
 					"netload", 
 					GetNet);
