@@ -75,6 +75,7 @@ typedef struct {
 	GtkWidget *pct_label;
 	GtkWidget *pixmap;
 	GtkWidget *box;
+	GtkWidget *about_dialog;
 	guint timeout_handler_id;
 	FILE *file;
 	GtkTooltips *tips;
@@ -548,21 +549,27 @@ wireless_applet_help_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 static void
 wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf *pixbuf;
 	char *file;
+
 	const gchar *authors[] = {
 		"Eskil Heyn Olsen <eskil@eskil.org>",
 		"Bastien Nocera <hadess@hadess.net> (Gnome2 port)",
 		NULL
 	};
-	const gchar *documenters[] = { NULL };
+
+	const gchar *documenters[] = { 
+                 "Sun GNOME Documentation Team <gdocteam@sun.com>",
+ 	        NULL 
+         };	
+
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about != NULL)
-	{
-		gtk_widget_show (about);
-		gtk_window_present (GTK_WINDOW (about));
+	if (applet->about_dialog != NULL) {
+		gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (&applet->base)));
+		
+		gtk_window_present (GTK_WINDOW (applet->about_dialog));
 		return;
 	}
 
@@ -571,7 +578,7 @@ wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 
-	about = gnome_about_new (
+	applet->about_dialog = gnome_about_new (
 			_("Wireless Link Monitor"),
 			VERSION,
 			_("(C) 2001, 2002 Free Software Foundation "),
@@ -582,11 +589,12 @@ wireless_applet_about_cb (BonoboUIComponent *uic, WirelessApplet *applet)
 			pixbuf);
 
 	g_object_unref (pixbuf);
-	
-	gtk_widget_show (about);
 
-	g_object_add_weak_pointer (G_OBJECT (about),
-			(void**)&about);
+	g_signal_connect (applet->about_dialog, "destroy",
+			  G_CALLBACK (gtk_widget_destroyed),
+			  &applet->about_dialog);
+ 
+	gtk_widget_show (applet->about_dialog);
 
 	return;
 }
@@ -641,6 +649,11 @@ wireless_applet_destroy (WirelessApplet *applet, gpointer horse)
 	for (i = 0; i < PIX_NUMBER; i++)
 		g_object_unref (applet->pixmaps[i]);
 
+	if (applet->about_dialog) {
+		gtk_widget_destroy (applet->about_dialog);
+		applet->about_dialog = NULL;
+	}
+
 	if (applet->prefs) {
 		gtk_widget_destroy (applet->prefs);
 		applet->prefs = NULL;
@@ -717,6 +730,7 @@ setup_widgets (WirelessApplet *applet)
 	gtk_container_add (GTK_CONTAINER (applet), applet->box);
 
 	applet->current_pixbuf = NULL;
+	applet->about_dialog = NULL;
 }
 
 static void change_size_cb(PanelApplet *pa, gint s, WirelessApplet *applet)
@@ -734,6 +748,8 @@ static void change_orient_cb(PanelApplet *pa, gint s, WirelessApplet *applet)
 static GtkWidget *
 wireless_applet_new (WirelessApplet *applet)
 {
+	AtkObject *atk_obj;
+
 	panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
 
 	/* this ensures that properties are loaded */
@@ -776,6 +792,13 @@ wireless_applet_new (WirelessApplet *applet)
 		(CFG_UPDATE_INTERVAL * 1000,
 		 (GtkFunction)wireless_applet_timeout_handler,
 		 applet);
+
+	atk_obj = gtk_widget_get_accessible (GTK_WIDGET (applet));
+
+	if (GTK_IS_ACCESSIBLE (atk_obj)) {
+		atk_object_set_name (atk_obj, _("Wireless Link Monitor"));
+		atk_object_set_description (atk_obj, _("This utility shows the status of a wireless link"));
+	}
 		 
 	g_signal_connect (G_OBJECT (applet), "change_size",
 				  G_CALLBACK (change_size_cb), applet);
